==> haskell-bytes-0.17.4-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-EbRff0NehMc3zvdqFLNPzn
key:                  bytes-0.17.4-EbRff0NehMc3zvdqFLNPzn
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  bde022675cafdc5ae2732c4f350ba7fa
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-EbRff0NehMc3zvdqFLNPzn
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-DY5k58eIhfKFYYD15f4NtB bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytes-0.17.4-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-AJIX0KHm1jM7VNv8uaO8ao
key:                  bytes-0.17.4-AJIX0KHm1jM7VNv8uaO8ao
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  bcc4525b73cfde0b4a3ae400339c8d50
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-AJIX0KHm1jM7VNv8uaO8ao
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-K8jgj6oc4SfL1ex39Egp61 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
